@@ -1066,9 +1066,6 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -1640,9 +1637,6 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -2216,9 +2210,6 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
